import socket


class returnips:

    def tryconvert(fqdn):
        try:
            if fqdn is None:
                return None
            else:
                ipaddr = socket.gethostbyname_ex(fqdn)[2]
                lst = [ip + "/32" for ip in ipaddr]
                return lst
        except:
            pass



import socket
from pyspark.sql import SparkSession
import pandas as pd
from parseudr.convertfqdntoip import returnips


class getfqdnips:
    def donslookup():
        spark = SparkSession.builder.getOrCreate()
        url = "https://docs.microsoft.com/en-us/azure/databricks/administration-guide/cloud-configurations/azure/udr"
        df = pd.read_html(url, header=0)[2]
        pdf1 = df.assign(
            FQDN=df["FQDN"].str.replace("net", "net\n").str.split("\n")
        ).explode("FQDN")
        pdf2 = pdf1.assign(
            FQDN=pdf1["FQDN"].str.replace("com", "com\n").str.split("\n")
        ).explode("FQDN")
        pdf2 = pdf2[pdf2["FQDN"] != ""]
        pdf2["IPAddress"] = pdf2["FQDN"].map(
            lambda host: returnips.tryconvert(host) if host is not None else host
        )
        sdf = spark.createDataFrame(pdf2)
        sdf.createOrReplaceTempView("UDR")
        return sdf


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()


setuptools.setup(
     name='parseudr',
     version='0.1.8',
    #  scripts=['storagemodel', 'trainmodel'] ,
     author="Arvind Ravish",
     author_email="arvind.ravish@gmail.com",
     description="A simple package to get Databricks FQDN IP addresses",
     long_description=long_description,
   long_description_content_type="text/markdown",
     url="",
     packages=['parseudr'],  #setuptools.find_packages(),
      #  py_modules=['storagemodel'],
    install_requires=[
        'pandas', 'lxml'
    ],
     classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
     ],
 )